function buildSnapTest(navWindow){
	//A simple window that lets you snap the the view at the click point.
	var win = Ti.UI.createWindow({
	    backgroundColor:'white',
	    title:'Snap'
	});

	var theView = Ti.UI.createView({
	    width:50,
	    height:50,
	    backgroundColor:'green',
	    center:{x:'50%',y:'50%'}
	});

	win.add(theView);

	var label = Ti.UI.createLabel({
		top:0,
		width:Ti.UI.FILL,
		color:'red'
	})
;
	win.add(label);

	var animator = Ti.UI.iOS.createAnimator({
	    referenceView:win
	});

	var snapbehavior = Ti.UI.iOS.createSnapBehavior({
	    item:theView,
	    damping:0
	});

	animator.addBehavior(snapbehavior);

    animator.addEventListener('pause',function(){
        label.text = 'ANIMATOR PAUSE EVENT';
    });

    animator.addEventListener('resume',function(){
        label.text = 'ANIMATOR RESUME EVENT';
    });
	win.addEventListener('click',function(e){
	    var snapPoint = {x:e.x,y:e.y};
	    if (e.source != win) {
	        var newPoint = e.source.convertPointToView(snapPoint,win);
	        snapPoint.x = newPoint.x;
	        snapPoint.y = newPoint.y;
	    };
	    if (animator) {
	        snapbehavior.snapPoint = snapPoint;
	        if (animator.running == false) {
	            animator.startAnimator();
	        };

	    } else {
	        Ti.API.error('NO ANIMATOR OBJECT');
	    };
	});

	win.addEventListener('blur',function(){
		//In a nav Window this event occurs before the view detaches so this is a 
		//good place to remove behaviors which also stops animator
		animator.removeAllBehaviors();
	});

	navWindow.openWindow(win);

}

function buildForcesTest(navWindow){
	var win = Ti.UI.createWindow({
	    backgroundColor:'white',
	    title:'Forces',
	    layout:'vertical'
	});

	var desc = Ti.UI.createLabel({
		width:Ti.UI.FILL,
		text:'This test shows the PUSH & GRAVITY behaviors with Collision (boundary) and DynamicItem (elasticity,resistance).\nRed has Gravity, Green has instantaneous push, Blue has continuous push.\nThe angle is PI/2 and magnitude 1.',
		font:{fontSize:8}
	});

	var btn = Ti.UI.createButton({title:'RUN'});
	
	var refView = Ti.UI.createView({
		borderColor:'black',
		borderWidth:1
	});

	win.add(desc);
	win.add(btn);
	win.add(refView);

	var gView = Ti.UI.createView({
		borderColor:'cyan',
		borderWidth:0,
	    width:50,
	    height:50,
	    backgroundColor:'red',
	    center:{x:'50',y:'50'}
	});

	var pIView = Ti.UI.createView({
		borderColor:'cyan',
		borderWidth:0,
	    width:50,
	    height:50,
	    backgroundColor:'green',
	    center:{x:'150',y:'50'}
	});

	var pCView = Ti.UI.createView({
		borderColor:'cyan',
		borderWidth:0,
	    width:50,
	    height:50,
	    backgroundColor:'blue',
	    center:{x:'250',y:'50'}
	});

	refView.add(gView);
	refView.add(pIView);
	refView.add(pCView);

	var animator = Ti.UI.iOS.createAnimator({
	    referenceView:refView
	});

	var options = {angle:Math.PI/2,magnitude:1};
	//Set up Forces Behavior
	var gravity = Ti.UI.iOS.createGravityBehavior(options);
	var pushI = Ti.UI.iOS.createPushBehavior(options);
	var pushC = Ti.UI.iOS.createPushBehavior(options);
	pushI.setPushMode(Ti.UI.iOS.PUSH_MODE_INSTANTANEOUS);
	pushC.setPushMode(Ti.UI.iOS.PUSH_MODE_CONTINUOUS);
	gravity.addItem(gView);
	pushI.addItem(pIView);
	pushC.addItem(pCView);

	//Set up Collision Behavior
	var collision = Ti.UI.iOS.createCollisionBehavior({treatReferenceAsBoundary:true});
	collision.addItem(gView);
	collision.addItem(pIView);
	collision.addItem(pCView);

	collision.addEventListener('boundarycollision',function(e){
		if(e.start == true) {
			Ti.API.info('COLLISION STARTED AT POINT ('+e.point.x+','+e.point.y+')');
			e.item.borderWidth = e.item.borderWidth + 1;
		} else {
			Ti.API.info('COLLISION ENDED');
		}
	});
	

	//Set up Dynamic Item
	var dynamic = Ti.UI.iOS.createDynamicItemBehavior({elasticity:0.5,resistance:0.5});
	dynamic.addItem(gView);
	dynamic.addItem(pIView);
	dynamic.addItem(pCView);


	animator.addBehavior(gravity);
	animator.addBehavior(pushI);
	animator.addBehavior(pushC);
	animator.addBehavior(collision);
	animator.addBehavior(dynamic);

	btn.addEventListener('click',function(e){
		animator.startAnimator();
	});

	win.addEventListener('blur',function(){
		//In a nav Window this event occurs before the view detaches so this is a 
		//good place to remove behaviors which also stops animator
		animator.removeAllBehaviors();
	});

	navWindow.openWindow(win);

}

function buildAnchorTest(navWindow){
	//A simple window that lets you snap the the view at the click point.
	var win = Ti.UI.createWindow({
	    backgroundColor:'white',
	    title:'Attachment',
	    layout:'vertical'
	});

	var desc = Ti.UI.createLabel({
		width:Ti.UI.FILL,
		text:'This test shows the ANCHOR behaviors.\nRed View will attach to anchor point (pointed to by the Blue View).Anchor Point is where ever you click in the reference view.\nA continuous push is applied to the Red View.'+
		' It should animate around the Blue View.\nGreen View is attached to Red View with a length of 20. It should animate around the Red View.\nClick View to start animator',
		font:{fontSize:8}
	});
	
	var refView = Ti.UI.createView({
		borderColor:'black',
		borderWidth:1
	});

	win.add(desc);
	win.add(refView);

	var gView = Ti.UI.createView({
	    width:30,
	    height:30,
	    backgroundColor:'green',
	});

	var rView = Ti.UI.createView({
	    width:50,
	    height:50,
	    backgroundColor:'red',
	});

	var bView = Ti.UI.createView({
	    width:5,
	    height:5,
	    backgroundColor:'blue',
	});

	var vView = Ti.UI.createLabel({
		top:0,
		left:10,
		color:'red',
		font:{fontSize:8,fontStyle:'italic'},
		text:''
	});

	refView.add(rView);
	refView.add(gView);
	refView.add(bView);
	refView.add(vView);

	var animator = Ti.UI.iOS.createAnimator({
	    referenceView:refView
	});

	var snap = Ti.UI.iOS.createSnapBehavior({item:bView,damping:1});
	var anchor1 = Ti.UI.iOS.createAnchorAttachmentBehavior({item:rView});
	var anchor2 = Ti.UI.iOS.createViewAttachmentBehavior({item:gView,anchorItem:rView,length:20});
	var pushC = Ti.UI.iOS.createPushBehavior({pushMode:Ti.UI.iOS.PUSH_MODE_CONTINUOUS});
	pushC.addItem(rView);

	animator.addBehavior(snap);
	animator.addBehavior(anchor1);
	animator.addBehavior(anchor2);
	animator.addBehavior(pushC);

	var started = false;

	var oldPoint = {x:0,y:0};

	function genVector(snapPoint)
	{
		var x1 = snapPoint.x - oldPoint.x;
		var y1 = snapPoint.y - oldPoint.y;
		if (Math.abs(x1) > Math.abs(y1)) 
		{
			return ({x:x1/Math.abs(y1),y:y1/Math.abs(y1)});
		} else {
			return ({x:x1/Math.abs(x1),y:y1/Math.abs(x1)});
		};
	} 

	refView.addEventListener('click',function(e){
	    var snapPoint = {x:e.x,y:e.y};
	    if (e.source != refView) {
	        var newPoint = e.source.convertPointToView(snapPoint,refView);
	        snapPoint.x = newPoint.x;
	        snapPoint.y = newPoint.y;
	    };
	    snap.snapPoint = snapPoint;
	    anchor1.anchor = snapPoint;
	    var v = genVector(snapPoint);
	    vView.text = 'Force Vector (x:'+v.x+',y:'+v.y+')';
	    pushC.pushDirection = v;
	    oldPoint = snapPoint;
        if (started == false) {
        	started = true;
            animator.startAnimator();
        };
	});

	win.addEventListener('blur',function(){
		//In a nav Window this event occurs before the view detaches so this is a 
		//good place to remove behaviors which also stops animator
		animator.removeAllBehaviors();
	});
	
	navWindow.openWindow(win);

}

module.exports = {
	snapTest:buildSnapTest,
	forceTest:buildForcesTest,
	anchorTest:buildAnchorTest
};